@@ -3,12 +3,14 @@ from .event import Event
 from .eventpayloaddescriptor import EventPayloadDescriptor
 from .interval import Interval
 from .intervalperiod import IntervalPeriod
-from .objectoperation import ObjectOperation, ObjectTypes, OperationTypes
+from .objectoperation import ObjectOperation, ObjectType, OperationType
+from .problem import Problem
 from .report import Report
 from .reportdata import ReportData
 from .reportdescriptor import ReportDescriptor
 from .reportpayloaddescriptor import ReportPayloadDescriptor
 from .subscription import Subscription
+from .targettype import TargetType
 from .valuesmap import Point, ValuesMap
 
 __all__ = [
@@ -18,13 +20,15 @@ __all__ = [
     "Interval",
     "IntervalPeriod",
     "ObjectOperation",
-    "ObjectTypes",
-    "OperationTypes",
+    "ObjectType",
+    "OperationType",
+    "Problem",
     "Point",
     "Report",
     "ReportData",
     "ReportDescriptor",
     "ReportPayloadDescriptor",
     "Subscription",
+    "TargetType",
     "ValuesMap",
 ]
